import { ɵɵdefineInjectable, Injectable, EventEmitter, Component, Input, Output, NgModule } from '@angular/core';
import { Subject } from 'rxjs';
import { JnyPreHttpServicesService } from 'jny-pre-http-services';
import { CommonModule } from '@angular/common';
import { FormsModule } from '@angular/forms';
import { DialogModule } from 'primeng/dialog';
import { ButtonModule } from 'primeng/button';

class JnyUserPickerService {
    constructor() {
        this.dialogAlertSubject = new Subject();
    }
    // ===== loginModal (START)=====
    sendDialogAlertSubject(obj) {
        this.dialogAlertSubject.next(obj);
    }
    getDialogAlertSubject() {
        return this.dialogAlertSubject.asObservable();
    }
}
JnyUserPickerService.ɵprov = ɵɵdefineInjectable({ factory: function JnyUserPickerService_Factory() { return new JnyUserPickerService(); }, token: JnyUserPickerService, providedIn: "root" });
JnyUserPickerService.decorators = [
    { type: Injectable, args: [{
                providedIn: 'root'
            },] }
];
JnyUserPickerService.ctorParameters = () => [];

class JnyUserPickerComponent {
    constructor(httpService, jnyUserPickerService) {
        this.httpService = httpService;
        this.jnyUserPickerService = jnyUserPickerService;
        this.ctrlUrl = 'osjcEmpCtrl/';
        this.valueChange = new EventEmitter();
        this.userInfo = new EventEmitter();
        this.STORAGE_KEY = 'JNY_loginUser';
        this.selectEmp = {
            userNo: '',
            cname: ''
        };
    }
    ngOnInit() {
    }
    ngOnChanges(changes) {
        if (changes.value.previousValue == null && changes.value.currentValue != null) {
            this.selectEmp.userNo = changes.value.currentValue;
            this.selectEmp.cname = changes.selectEmpName.currentValue;
            this.checkAuth();
        }
    }
    changeUser() {
        if (this.value === '') {
            this.selectEmpName = '';
            this.userInfo.emit({ empNo: '', empName: '' });
        }
    }
    qryEmp(deptNo) {
        return this.httpService.post(this.ctrlUrl + 'qryEmp', deptNo);
    }
    // 挑選部門
    pickDept() {
        this.qryEmp(this.selectDept).subscribe((carrier) => {
            this.setEmpVos(carrier);
            this.addAuth();
        }, error => console.log(error));
    }
    pickUser(event) {
        this.checkAuth();
    }
    // 查詢目前登入的人是否有此使用者權限
    checkAuth() {
        const params = { empNo: this.selectEmp.userNo };
        this.httpService.post('oajcContactCtrl/queryEmpNo', params).subscribe((data) => {
            this.setValueEmit(data);
        }, error => { console.log(error); });
    }
    setValueEmit(data) {
        this.value = this.selectEmp.userNo;
        this.selectEmpName = this.selectEmp.cname;
        data.attributeMap.contactVO.empNo = this.selectEmp.userNo;
        data.attributeMap.contactVO.empName = this.selectEmp.cname;
        this.visible = false;
        this.valueChange.emit(this.value);
        this.userInfo.emit(data.attributeMap.contactVO);
    }
    // 開啟使用者挑選清單
    showUserPicker() {
        this.queryDeptVOs();
        this.getUserByDept();
        //  this.getUserInfo();
    }
    // 依照部門代碼取得使用者清單
    getUserByDept() {
        let loginUserVO = this.getLoginUser();
        if (this.value != null && this.value !== '') {
            // 使用者輸入欄已有值時，預設將使用者選單選到該選項,部門選單則不選到任何值
            this.selectDept = '';
            this.qryEmpBySameDept(this.value);
        }
        else {
            // 使用者輸入欄無值時，選單預設選到為登入者的部門和職鯿
            this.selectDept = loginUserVO.deptNo;
            this.qryEmpBySameDept(loginUserVO.userId);
        }
        this.visible = true;
    }
    qryEmpBySameDept(empNo) {
        this.httpService.post(this.ctrlUrl + 'qryEmpBySameDept', empNo).subscribe((carrier) => {
            this.setEmpVos(carrier);
            this.selectEmp.userNo = empNo;
        }, error => { console.error(error); });
    }
    setEmpVos(carrier) {
        let mapArray = carrier.attributeMap['empList'];
        this.empVOs = new Array();
        for (let i = 0; i < mapArray.length; i++) {
            let map = mapArray[i];
            let empVO = new EmpVO();
            empVO.userNo = map['USERNO'];
            empVO.cname = map['CNAME'];
            empVO.deptNo = map['DEPTNO'];
            empVO.hasAuth = '0';
            this.empVOs.push(empVO);
        }
    }
    // empVOs 添加 auth 權限
    addAuth() {
        let auth_list = JSON.parse(sessionStorage.getItem('auth-list'));
        if (auth_list == null) {
            return;
        }
        this.empVOs.forEach(function (mval) {
            auth_list.forEach(function (aval) {
                if (mval.userNo === aval.empNo) {
                    mval.hasAuth = aval.hasAuth;
                }
            });
        });
    }
    queryDeptVOs() {
        this.httpService.post(this.ctrlUrl + 'qryAllDept').subscribe((carrier) => {
            let mapArray = carrier.attributeMap['deptList'];
            this.deptVOs = new Array();
            for (let i = 0; i < mapArray.length; i++) {
                let map = mapArray[i];
                let deptVO = new DeptVO();
                deptVO.deptNo = map['DEPTNO'];
                deptVO.deptName = map['DEPTNAME'];
                this.deptVOs.push(deptVO);
            }
        }, error => console.log(error));
    }
    getLoginUser() {
        let loginUserVO = JSON.parse(sessionStorage.getItem(this.STORAGE_KEY));
        if (loginUserVO == null || loginUserVO == undefined) {
            return new LoginUserVO();
        }
        else {
            return loginUserVO;
        }
    }
}
JnyUserPickerComponent.decorators = [
    { type: Component, args: [{
                selector: 'lib-jny-user-picker',
                template: "<style>\r\n  .myBox {\r\n    display: inline-block;\r\n  }\r\n\r\n  .uidText {\r\n    width: 60px;\r\n  }\r\n</style>\r\n\r\n<div class=\"p-inputgroup\">\r\n  <input type=\"text\" pInputText [(ngModel)]=\"value\" (change)=\"changeUser()\" class='uidText'>\r\n  <span class=\"p-inputgroup-addon\">{{selectEmpName}}</span>\r\n  <button type=\"button\" pButton pRipple icon=\"pi pi-user\" styleClass=\"p-button-warn\"\r\n    (click)=\"showUserPicker()\"></button>\r\n</div>\r\n\r\n<p-dialog header=\"\u4F7F\u7528\u8005\u6311\u9078\" [(visible)]=\"visible\" [responsive]=\"true\" [style]=\"{width: '450px', minWidth: '400px'}\"\r\n  [maximizable]=\"true\" [baseZIndex]=\"10000\">\r\n  <div style=\"text-align: center\">\r\n    <div class=\"myBox\">\r\n      <!--\u56E0IE\u4E0B\u62C9\u9078\u55AEoption\u6C92\u6709click\u4E8B\u4EF6\uFF0C\u6545\u5BEB\u5728select\u4E2D-->\r\n      <select [(ngModel)]=\"selectDept\" size=\"20\" (click)=\"pickDept()\" style=\"width:200px\">\r\n        <option *ngFor=\"let deptVO of deptVOs\" [value]=\"deptVO.deptNo\">{{deptVO.deptNo + ' '+ deptVO.deptName}}</option>\r\n      </select>\r\n    </div>\r\n    <div class=\"myBox\" style=\"margin-left:5px\">\r\n      <select [(ngModel)]=\"selectEmp\" size=\"20\" (click)=\"pickUser($event)\" id=\"pickUserSelect\" style=\"width:200px\">\r\n        <option *ngFor=\"let empVO of empVOs\" [ngValue]=\"empVO\">\r\n          <!--[disabled]=\"empVO.hasAuth!=='1'\"-->\r\n          <!--[value]=\"empVO.userNo\"-->\r\n          {{empVO.cname}}\r\n        </option>\r\n      </select>\r\n    </div>\r\n  </div>\r\n</p-dialog>\r\n",
                providers: []
            },] }
];
JnyUserPickerComponent.ctorParameters = () => [
    { type: JnyPreHttpServicesService },
    { type: JnyUserPickerService }
];
JnyUserPickerComponent.propDecorators = {
    value: [{ type: Input }],
    selectEmpName: [{ type: Input }],
    valueChange: [{ type: Output }],
    userInfo: [{ type: Output }]
};
class DeptVO {
}
class EmpVO {
}
class LoginUserVO {
    constructor() {
        this.tokenId = '';
        this.userId = '';
        this.userName = '';
        this.postId = '';
        this.postName = '';
        this.deptNo = '';
        this.deptName = '';
    }
}

class JnyDialogAlertComponent {
    constructor(jnyUserPickerService) {
        this.jnyUserPickerService = jnyUserPickerService;
        this.display = false;
        this.subscription = this.jnyUserPickerService.getDialogAlertSubject().subscribe((obj) => {
            this.display = obj['display'];
            this.header = obj['header'];
            this.content = obj['content'];
        });
    }
    ngOnInit() {
    }
    ngOnDestroy() {
        this.subscription.unsubscribe();
    }
}
JnyDialogAlertComponent.decorators = [
    { type: Component, args: [{
                selector: 'lib-jny-dialog-alert',
                template: "<p-dialog [header]=\"header\" [(visible)]=\"display\">\n  {{content}}\n</p-dialog>\n",
                styles: [""]
            },] }
];
JnyDialogAlertComponent.ctorParameters = () => [
    { type: JnyUserPickerService }
];

class JnyUserPickerModule {
}
JnyUserPickerModule.decorators = [
    { type: NgModule, args: [{
                declarations: [JnyUserPickerComponent, JnyDialogAlertComponent],
                imports: [
                    FormsModule,
                    CommonModule,
                    DialogModule,
                    ButtonModule
                ],
                exports: [JnyUserPickerComponent, JnyDialogAlertComponent]
            },] }
];

/*
 * Public API Surface of jny-user-picker
 */

/**
 * Generated bundle index. Do not edit.
 */

export { DeptVO, EmpVO, JnyDialogAlertComponent, JnyUserPickerComponent, JnyUserPickerModule, JnyUserPickerService, LoginUserVO };
//# sourceMappingURL=jny-user-picker.js.map
